FUNCTION dingo2,smov

;Calculation of number, total area, statictics of effective diameters
;of umbral dots in a segmented (after UDISOL.PRO) movie or image SMOV.
;Procedure OBJEKT1 is used for identification of UDs.
;OUTPUT: 2-D array/table with 6 columns. In case of a single frame it
;is a single row.
;Column 0 - number of UDs
;	1 - total area of UDs in pixels
;	2 - min. effective diameter of UDs (")
;	3 - max.         -- " --
;	4 - mean         -- " --
;	5 - stdev of     -- " --
;
;CALLING SEQUENCE:  res=dingo2(smov)
;
; ************* PARAMETER ***************
scale=0.125   ;image scale arcsec/pix
; ***************************************

s=size(smov)
if (s(0) lt 2) or (s(0) gt 3) then RETURN,0	;error case

if s(0) eq 2 then begin		;single frame case
   out=fltarr(6)
   OBJEKT1,smov,tab
   out(0)=max(tab(0,*))		;max.object no.= number of objects
   w=where(tab(0,*),c)		;c=total number of object pixels
   out(1)=c			; =total area of UDs (pix)
   diam=fltarr(out(0))		;array of effective diameters
   for j=1,out(0) do begin	;loop over objects
      w=where(tab(0,*) eq j,c)  ;c=number of pixels in j-th object
      diam(j-1)=scale*sqrt(4*c/!pi)
   endfor
   out(2)=min(diam,max=ma)	;min, max of diam
   out(3)=ma
   out(5)=stdev(diam,me)	;stdev, mean of diam
   out(4)=me
endif

if s(0) eq 3 then begin		;movie case
   out=fltarr(6,s(3))
   for i=0,s(3)-1 do begin	;loop over frames
     ima=smov(*,*,i)
     OBJEKT1,ima,tab
     out(0,i)=max(tab(0,*))	;max.object no.= number of objects
     w=where(tab(0,*),c)	;c=total number of object pixels
     out(1,i)=c			; =total area of UDs (pix)
     diam=fltarr(out(0,i))	;array of effective diameters
     for j=1,out(0,i) do begin	;loop over objects
       w=where(tab(0,*) eq j,c) ;c=number of pixels in j-th object
       diam(j-1)=scale*sqrt(4*c/!pi)
     endfor
     out(2,i)=min(diam,max=ma)	;min, max of diam
     out(3,i)=ma
     out(5,i)=stdev(diam,me)	;stdev, mean of diam
     out(4,i)=me
   endfor
endif

RETURN,out
end

