PRO binavglif

;The procedure computes average values of lifetimes-vs-cdist
;distribution in 10 bins along the relative distance in the
;penumbra and plots it in a .PS figure 'binavgv.ps'.
;The lifetimes are computed by AVGLIFE.PRO, i.e. they
;are derived from average birth rate of PGs.
;Used for Suetterlin's penumbra.
;
; The info is extracted from vxy10i.log, vxy10o.log
; and from 'trim'
; Optional output to ps/eps files.
; 3 May 2000

;reading data

restore,'vxy/vxy10i.log'
restore,'vxy/vxy10o.log'
ddi=reform(vxylogi(3,*))	; distances w.r. to center (")
ddo=reform(vxylogo(3,*))

restore,'trim'
trim=merge(triml,trimt)
trim=merge(trim,trimr)
trim=merge(trim,trimb)	; putting together all quadrants
triml=0
trimt=0
trimr=0
trimb=0


;normalization of positions to 0--1 (min--max)

ddi=ddi>7.3	;setting artifitial boundaries at 7.3" and 18.5"
ddi=ddi<18.5	;  to compensate for the slight asymmetry
ddo=ddo>7.3
ddo=ddo<18.5

m0i=min(ddi)
m0o=min(ddo)
m0=m0i<m0o
m1i=max(ddi)
m1o=max(ddo)
m1=m1i>m1o
dni=(ddi-m0)/(m1-m0) < 0.999	;relative distances
dno=(ddo-m0)/(m1-m0) < 0.999

;Travel speeds ----------------------------------------------

;bins 0-.1 ... .9 - 1

lti=fltarr(10)
lto=fltarr(10)
ci=lonarr(10)
co=lonarr(10)

for i=0,9 do begin
  print,i
  wi=where(dni ge i/10. and dni lt (i+1)/10.,cii)
  wo=where(dno ge i/10. and dno lt (i+1)/10.,coo)
  idi=vxylogi(0,wi)	; ident.numbers
  ido=vxylogo(0,wo)
  tri=trim(*,*,idi)
  tro=trim(*,*,ido)
  AVGLIFE,tri,lifi
  AVGLIFE,tro,lifo
  if cii lt 10 then lifi=(-10)	;eliminate bins with too small
  if coo lt 10 then lifo=(-10)	;  number of PGs (<10)
  lti(i)=lifi
  lto(i)=lifo
  ci(i)=cii
  co(i)=coo

endfor

xx=indgen(10)/10.+0.05

  set_plot,'ps'
  device,filename='binavglif.ps',xsiz=15,ysiz=11,yoffs=14,encapsulated=0
;  device,filename='binavglif.eps',xsiz=15,ysiz=11,yoffs=14,encapsulated=1

  plot,xx,lti,psym=7,yra=[0,100], thick=2,xthick=2,ythick=2, $
   symsiz=1.1,/yst,  $
   ytitle='Average Lifetime (minutes)',charsiz=1.1,charthick=2,  $
   xtitle='Relative Position in the Penumbra'
  oplot,xx,lto,psym=6,symsiz=1.1,thick=2

;plotting number of PGs in each bin
for i=0,9 do begin
   if ci(i) lt 10 then goto,bkipi
   xyouts,xx(i)-0.03,90,strtrim(ci(i),2),/data,charsiz=1.1,charthick=2
  bkipi:
endfor
for i=0,9 do begin
   if co(i) lt 10 then goto,bkipo
   xyouts,xx(i)-0.03,83,strtrim(co(i),2),/data,charsiz=1.1,charthick=2
  bkipo:
endfor
;oplot,[0.15],[1.42],psym=7,symsiz=1.1,thick=2
;xyouts,0.18,1.4,'= INW',charsiz=1.1,charthick=2
;oplot,[0.15],[1.32],psym=6,symsiz=1.1,thick=2
;xyouts,0.18,1.3,'= OUT',charsiz=1.1,charthick=2

  device,/close
  set_plot,'x'

end
