PRO fig_trp,ima,ps=ps

; A program to visualize trajectories of features penetrating into P4
; from the MANTRACK result files r* and r0ffxy.

;INPUTS:  ima  - underlying image
;	  ps   - keyword. If set, PS figure is made
;OUTPUT:  on the screen OR to PS-file (depends if ps is set):
;	   Image of the field with smoothed trajectories of PGs
;		(PS file  rtraj.ps)
;
;CALLING SEQUENCE:    fig_trp,image[,/ps]

;==================================================================
;Parameters
	reb=2		;  rebin factor for visualization
;==================================================================

si=size(ima)
loadct,0

if keyword_set(ps) then begin
  set_plot,'ps'
  device,file='rtraj.ps',bits_per_pixel=8,/color,/portrait, $
    yoffset=10,xsize=si(1)*0.05,ysize=si(2)*0.05      ;centimeters
  tvscl,ima
  reb=50			;1000 PS points/cm, 20 pix/cm
endif else begin
  window,2,xsiz=si(1)*reb,ysiz=si(2)*reb
  tvscl,rebin(ima,si(1)*reb,si(2)*reb)
endelse

restore,'r0ffxy'
for i=1,14 do  restore,'r'+strtrim(i,2)

;Trajectory plots


xx=(r1(1,*)+r0ffxy(0,0))*reb
yy=(r1(2,*)+r0ffxy(1,0))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r2(1,*)+r0ffxy(0,1))*reb
yy=(r2(2,*)+r0ffxy(1,1))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r3(1,*)+r0ffxy(0,2))*reb
yy=(r3(2,*)+r0ffxy(1,2))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r4(1,*)+r0ffxy(0,3))*reb
yy=(r4(2,*)+r0ffxy(1,3))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r5(1,*)+r0ffxy(0,4))*reb
yy=(r5(2,*)+r0ffxy(1,4))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r6(1,*)+r0ffxy(0,5))*reb
yy=(r6(2,*)+r0ffxy(1,5))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r7(1,*)+r0ffxy(0,6))*reb
yy=(r7(2,*)+r0ffxy(1,6))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r8(1,*)+r0ffxy(0,7))*reb
yy=(r8(2,*)+r0ffxy(1,7))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r9(1,*)+r0ffxy(0,8))*reb
yy=(r9(2,*)+r0ffxy(1,8))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r10(1,*)+r0ffxy(0,9))*reb
yy=(r10(2,*)+r0ffxy(1,9))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r11(1,*)+r0ffxy(0,10))*reb
yy=(r11(2,*)+r0ffxy(1,10))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r12(1,*)+r0ffxy(0,11))*reb
yy=(r12(2,*)+r0ffxy(1,11))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r13(1,*)+r0ffxy(0,12))*reb
yy=(r13(2,*)+r0ffxy(1,12))*reb
plots,xx,yy,/device,col=0,thick=3

xx=(r14(1,*)+r0ffxy(0,13))*reb
yy=(r14(2,*)+r0ffxy(1,13))*reb
plots,xx,yy,/device,col=0,thick=3

if keyword_set(ps) then begin
  device,/close
  set_plot,'x'
endif

end
