PRO wiener_br,a,mtf1,mtf2,wf1,wf2

; Calculation of 1-D theoretical MTFs of a diffraction-limited telescope
; and corresponding Wiener filters (with constant or variable SNR),
; in two wavelengths, with an optional PS plot.
;

;**********************************************************************

	STP=0.041	  ; STEP OF RESTORED IMAGES (arcsec/pix)
	lambda2=6.020d-5  ; WORKING WAVELENGTH (cm)
	lambda1=4.507d-5
	n=1024		  ; SIZE (LENGTH) OF ARRAY (pixels)
	d=97.		  ; DIAMETER OF THE TELESCOPE (cm)

;**********************************************************************

        a=findgen(n/2+1)/(n*stp)        ; scale array for plotting
	mtf1=dblarr(n)
	mtf2=dblarr(n)
	cc1=lambda1*2.062648d5/(d*n*STP)  ; 206264.8 arcsec in radian
	cc2=lambda2*2.062648d5/(d*n*STP)

	ss=0
	for i=1,n do begin
	      
	   omega=cc1*(i-1)
	   if omega lt 1.d0 then begin
	        TT=acos(omega)-omega*sqrt(1.-omega^2)
	   endif else begin
                ss=ss+1
		if ss eq 1 then print,'MTF1 cutoff: ',i-1
	        TT=0.d0
	   endelse
	   mtf1(i-1)=2.*TT/3.141592654d0

	endfor

	ss=0
	for i=1,n do begin
	      
	   omega=cc2*(i-1)
	   if omega lt 1.d0 then begin
	        TT=acos(omega)-omega*sqrt(1.-omega^2)
	   endif else begin
                ss=ss+1
		if ss eq 1 then print,'MTF2 cutoff: ',i-1
	        TT=0.d0
	   endelse
	   mtf2(i-1)=2.*TT/3.141592654d0

	endfor

window,2,xsiz=512,ysiz=640
plot,a,mtf1,xra=[-0.2,12],yra=[-0.2,3.5],/xst,/yst,line=5
oplot,a,mtf2,line=4


; creating the 1-D Wiener filter ----------------------------------------

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; constant SNR:
;	read,'Filter parameter C = ',c
;	wf=(c+1)*mtf/(c*mtf*mtf+1)
;	oplot,a,wf,linestyle=5
;	oplot,a,wf*mtf,line=3
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; linear SNR:
	read,'Filter parameters K, fo : ',k,fo
	fp=nint(fo*n*stp)	; conversion to pixels

	wf1=dblarr(n)		; filter1
	wf2=dblarr(n)		; filter2
	uu=findgen(n-fp-1)+1.	; linearly increasing N/S
	uu=uu/n/stp
	wf1(0:fp)=1./mtf1(0:fp)
	wf1(fp+1:n-1)=mtf1(fp+1:n-1)/(mtf1(fp+1:n-1)^2+k*uu)
	wf2(0:fp)=1./mtf2(0:fp)
	wf2(fp+1:n-1)=mtf2(fp+1:n-1)/(mtf2(fp+1:n-1)^2+k*uu)
	oplot,a,wf1
	oplot,a,wf2,line=3

; hardcopy:

print,'Do you want a PS figure ? (y/n)'
if get_kbrd(1) eq 'y' then begin
	set_plot,'ps'
	device,file='wiener_br.ps',xsiz=12,ysiz=11,yoffs=14,encapsulated=0
	plot,a,mtf1,xra=[-0.2,12],yra=[-0.2,3.5],/xst,/yst,  $
	  xtitle='Frequency (arcsec)!U-1!N',  $
	  ytitle='MTF and Restoration Filter',line=5
	oplot,a,mtf2,line=4
	oplot,a,wf1,line=0
	oplot,a,wf2,line=3
	plots,[-0.2,12],[0,0],line=2
	xyouts,7.5,3.2,'!3D = '+strtrim(fix(d),2)+' cm'
	xyouts,7.5,3,'!4k!3!D1!N = '+strtrim(nint(lambda1*1.e7),2)+' nm'
	xyouts,7.5,2.8,'!4k!3!D2!N = '+strtrim(nint(lambda2*1.e7),2)+' nm'
	xyouts,4.5,2.2,'!4k!3!D1!N'
	xyouts,4.5,3.15,'!4k!3!D2!N'
	device,/close
	set_plot,'x'
endif

end


